==> igniteui-angular-charts-14.1.1.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return ChaikinVolatilityIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get u2() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.u3));
        }
        set u2(a) {
            this.h(ChaikinVolatilityIndicator.u3, a);
        }
        un() {
            return this.u2;
        }
        uw(a) {
            this.u2 = a;
        }
    }
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.u3 = StrategyBasedIndicator.uz(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();

==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return ChaikinVolatilityIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get u6() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.u7));
        }
        set u6(a) {
            this.h(ChaikinVolatilityIndicator.u7, a);
        }
        ur() {
            return this.u6;
        }
        u0(a) {
            this.u6 = a;
        }
    }
    ChaikinVolatilityIndicator.$t = markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.u7 = StrategyBasedIndicator.u3(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();
